@@ -101,45 +101,6 @@ anjuta_profile_error_get_type (void)
   return etype;
 }
 
-/* enumerations from "anjuta-preferences.h" */
-GType
-anjuta_property_object_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE, "ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE", "toggle" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_SPIN, "ANJUTA_PROPERTY_OBJECT_TYPE_SPIN", "spin" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY, "ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY", "entry" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_COMBO, "ANJUTA_PROPERTY_OBJECT_TYPE_COMBO", "combo" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_COLOR, "ANJUTA_PROPERTY_OBJECT_TYPE_COLOR", "color" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_FONT, "ANJUTA_PROPERTY_OBJECT_TYPE_FONT", "font" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_FILE, "ANJUTA_PROPERTY_OBJECT_TYPE_FILE", "file" },
-      { ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER, "ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER", "folder" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyObjectType"), values);
-  }
-  return etype;
-}
-GType
-anjuta_property_data_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { ANJUTA_PROPERTY_DATA_TYPE_BOOL, "ANJUTA_PROPERTY_DATA_TYPE_BOOL", "bool" },
-      { ANJUTA_PROPERTY_DATA_TYPE_INT, "ANJUTA_PROPERTY_DATA_TYPE_INT", "int" },
-      { ANJUTA_PROPERTY_DATA_TYPE_TEXT, "ANJUTA_PROPERTY_DATA_TYPE_TEXT", "text" },
-      { ANJUTA_PROPERTY_DATA_TYPE_COLOR, "ANJUTA_PROPERTY_DATA_TYPE_COLOR", "color" },
-      { ANJUTA_PROPERTY_DATA_TYPE_FONT, "ANJUTA_PROPERTY_DATA_TYPE_FONT", "font" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyDataType"), values);
-  }
-  return etype;
-}
-
 /* enumerations from "anjuta-launcher.h" */
 GType
 anjuta_launcher_output_type_get_type (void)
@@ -239,8 +200,9 @@ anjuta_project_property_flags_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GFlagsValue values[] = {
-      { ANJUTA_PROJECT_PROPERTY_READ_ONLY, "ANJUTA_PROJECT_PROPERTY_READ_ONLY", "only" },
-      { ANJUTA_PROJECT_PROPERTY_READ_WRITE, "ANJUTA_PROJECT_PROPERTY_READ_WRITE", "write" },
+      { ANJUTA_PROJECT_PROPERTY_READ_ONLY, "ANJUTA_PROJECT_PROPERTY_READ_ONLY", "read-only" },
+      { ANJUTA_PROJECT_PROPERTY_READ_WRITE, "ANJUTA_PROJECT_PROPERTY_READ_WRITE", "read-write" },
+      { ANJUTA_PROJECT_PROPERTY_HIDDEN, "ANJUTA_PROJECT_PROPERTY_HIDDEN", "hidden" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static (g_intern_static_string ("AnjutaProjectPropertyFlags"), values);
